@@ -894,7 +894,7 @@ void keyboard_command(chan_info *cp, int keysym, int unmasked_state)
 		else 
 		  {
 		    if (!(delete_mark_samp(cursor_sample(cp), cp)))
-		      status_report(cp->sound, "no mark at sample %" PRId64, cursor_sample(cp));
+		      status_report(cp->sound, "no mark at sample %" print_mus_long, cursor_sample(cp));
 		  }
 		if ((keysym == snd_K_M) && 
 		    (cp->sound->sync != 0))
@@ -919,7 +919,7 @@ void keyboard_command(chan_info *cp, int keysym, int unmasked_state)
 			  else 
 			    {
 			      if (!(delete_mark_samp(cursor_sample(cp), si->cps[i])))
-				status_report(cp->sound, "no mark at sample %" PRId64, cursor_sample(cp));
+				status_report(cp->sound, "no mark at sample %" print_mus_long, cursor_sample(cp));
 			    }
 			}
 		    si = free_sync_info(si);
@@ -1042,7 +1042,7 @@ void keyboard_command(chan_info *cp, int keysym, int unmasked_state)
 	      if (count > 0)
 		{
 		  start_selection_creation(cp, cursor_sample(cp));
-		  status_report(sp, "selection starts at %" PRId64, cursor_sample(cp));
+		  status_report(sp, "selection starts at %" print_mus_long, cursor_sample(cp));
 		}
 	      break;
 
@@ -1602,6 +1602,7 @@ static Xen g_bind_key_1(Xen key, Xen state, Xen code, Xen cx_extended, Xen origi
   else 
     {
       int args;
+      char buf[256];
       const char *comment = NULL, *prefs = NULL;
       args = Xen_required_args(code);
       if (args > 1)
@@ -1616,11 +1617,7 @@ static Xen g_bind_key_1(Xen key, Xen state, Xen code, Xen cx_extended, Xen origi
 	}
       if (Xen_is_string(origin))
 	comment = Xen_string_to_C_string(origin); 
-      else
-	{
-	  char buf[256];
-	  comment = make_key_name(buf, 256, k, s, e);
-	}
+      else comment = make_key_name(buf, 256, k, s, e);
       if (Xen_is_string(prefs_info)) prefs = Xen_string_to_C_string(prefs_info);
       set_keymap_entry(k, s, args, code, e, comment, prefs);
     }
