@@ -92,7 +92,7 @@
 (define-constant _1234_ 1234)
 (define _dilambda_ (dilambda (lambda (x) (+ x 1)) (lambda (x y) (+ x y))))
 (define __var2__ 3)
-(set! (symbol-setter '__var2__) (lambda (s v) (if (integer? v) v 3)))
+(set! (setter '__var2__) (lambda (s v) (if (integer? v) v 3)))
 
 (define (free1) (set! x (- (+ x 1) 1)))
 (define (free2) (x i))
@@ -366,7 +366,7 @@
 			  'provide 'call-with-output-string 
 			  'checked-hash-table 'checked-hash-table*
 			  'with-output-to-string 
-			  'symbol-setter 
+			  ;'symbol-setter 
 			  's7-version 
 			  'dilambda?
 			  'hook-functions 
@@ -452,7 +452,7 @@
 			  'arity 'logbit? 
 			  'random-state? 'throw 'float-vector-set! 'make-iterator 'complex 
 			  'let-ref 'int-vector 'aritable? 'gensym? 'syntax? 'iterator-at-end? 'let? 
-			  'make-shared-vector 'float-vector 'iterator-sequence 'getenv 'float-vector-ref 
+			  'subvector 'float-vector 'iterator-sequence 'getenv 'float-vector-ref 
 			  'cyclic-sequences 'let->list 
 			  
 			  'setter 'int-vector? 
@@ -609,7 +609,7 @@
 		    "(mock-hash-table* 'b 2)"
 
 		    ;;" #| a comment |# "
-		    "(make-shared-vector (vector 0 1 2 3 4) 3)" "(substring \"0123\" 2)"
+		    "(subvector (vector 0 1 2 3 4) 3)" "(substring \"0123\" 2)"
 		    "(vector-dimensions (block))" 
 		    "(append (block) (block))"
 		    "(let-temporarily ((x 1234)) (+ x 1))"
