@@ -2,8 +2,8 @@
 
 (require libc.scm)
 
-(set! (*s7* 'max-vector-length) (ash 1 33))
-(set! (*s7* 'max-string-length) (ash 1 33))
+(set! (*s7* 'max-vector-length) (ash 1 36))
+(set! (*s7* 'max-string-length) (ash 1 36))
 
 (load "s7test-block.so" (sublet (curlet) (cons 'init_func 'block_init)))
 
@@ -198,7 +198,7 @@
 ;; --------------------------------------------------------------------------------
 (format () "strings...~%")
 
-(when (> total-memory (* 2 big-size))
+(when (> total-memory (* 4 big-size))
   (clear-and-gc)
   (let ((bigstr (make-string big-size #\space)))
     (define (big-string-filler)
@@ -397,16 +397,18 @@
 	(test (morally-equal? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 0.25)
 	(test (morally-equal? big1 bigfv) #f)
-	(let ((big2 (make-shared-vector big1 (list 20) (- (ash 1 31) 10))))
+	(let ((big2 (subvector big1 (list 20) (- (ash 1 31) 10))))
 	  (test big2 (make-float-vector 20 0.5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-float-vector 20 0.0)))
 	    (copy bigfv big3 (- (ash 1 31) 10) (+ (ash 1 31) 10))
 	    (test (morally-equal? big2 big3) #t)))))
+
     (define (big-float-vector-filler)
       (do ((i 0 (+ i 1)))
 	  ((= i big-size))
 	(float-vector-set! bigfv i 1.0)))
+
     (big-float-vector-filler)
     (test (bigfv 1) 1.0)))
 
@@ -465,9 +467,27 @@
     (test (float-vector-ref bigfv1 0 (- (/ big-size 2) 1)) 1.0)
     (test (float-vector-ref bigfv2 1 (- (/ big-size 2) 1)) 2.0)
     (let ((bigfv3 (append bigfv1 bigfv2)))
-      (test (length bigfv3) big-size)
-      (test (float-vector-ref bigfv3 (- (/ big-size 2) 1)) 1.0)
-      (test (float-vector-ref bigfv3 (+ (/ big-size 2) 1)) 2.0))))
+      (test (length bigfv3) (* 2 big-size))
+      (test (float-vector-ref bigfv3 (- big-size 1)) 1.0)
+      (test (float-vector-ref bigfv3 (+ big-size 1)) 2.0))))
+
+(when (> total-memory (* 32 big-size))
+  (format () "test 3b~%")
+  (clear-and-gc)
+  (let ((bigfv1 (make-float-vector (* big-size 2) 1.0))
+	(bigfv2 (make-float-vector (* big-size 2) 2.0)))
+    (test (float-vector-ref bigfv1 (- (/ big-size 2) 1)) 1.0)
+    (test (float-vector-ref bigfv2 (- (/ big-size 2) 1)) 2.0)
+    (define (f-loop)
+      (do ((i (- (ash 1 32) 10) (+ i 1))
+	   (j 0 (+ j 1)))
+	  ((= i (+ (ash 1 32) 10)))
+	(set! (bigfv1 i) j)
+	(set! (bigfv2 i) (* (bigfv1 i) 2))))
+    (f-loop)
+    (test (subvector bigfv1 (list 20) (- (ash 1 32) 10)) (float-vector 0 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19))
+    (test (subvector bigfv2 (list 20) (- (ash 1 32) 10)) (float-vector 0 2 4 6 8 10 12 14 16 18 20 22 24 26 28 30 32 34 36 38))
+    (test (subvector bigfv1 (list 5) (+ (ash 1 32) 5)) (float-vector 15 16 17 18 19))))
 
 (when (> total-memory (* 9 big-size))
   (format () "test 4~%")
@@ -682,8 +702,8 @@
 	(set! mx (max mx (abs (float-vector-ref fvr 0 i)) (abs (float-vector-ref fvr 1 i)))))
       (format () "noise: ~A~%" mx))))
 
-(define (float-2d-test)
-  (let ((fvr (make-float-vector (list 2 fft-size) 0.0)))
+(define (float-2d-test skip)
+  (let ((fvr (make-float-vector (list skip fft-size) 0.0)))
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
 	((= i fft-size))
@@ -693,9 +713,24 @@
     (float-2d-fft #f fft-size 1)
     (float-2d-checker #f)))
 
-(float-2d-test)
+(float-2d-test 2)
+(clear-and-gc)
+(let-temporarily ((fft-size 32))
+  (float-2d-test 2))
+
+;; now try a big float-vector, but same size fft
+(when (> total-memory (* 9 (ash 1 31)))
+  (float-2d-test (ash 1 14))) ; fft-size (ash 1 17) -> (* 8 (ash 1 31))
+(let-temporarily ((fft-size 32))
+  (float-2d-test 2))
 (clear-and-gc)
 
+(when (> total-memory (* 9 (ash 1 33)))
+  (float-2d-test (ash 1 16))) ; fft-size (ash 1 17) -> (* 8 (ash 1 33))
+(let-temporarily ((fft-size 32))
+  (float-2d-test 2))
+(clear-and-gc)
+  
 
 ;; --------------------------------------------------------------------------------
 (format () "~%int-vectors...~%")  
@@ -709,7 +744,7 @@
 	(test (morally-equal? big1 bigfv) #t)
 	(set! (big1 (- big-size 1)) 25)
 	(test (morally-equal? big1 bigfv) #f)
-	(let ((big2 (make-shared-vector big1 (list 20) (- (ash 1 31) 10))))
+	(let ((big2 (subvector big1 (list 20) (- (ash 1 31) 10))))
 	  (test big2 (make-int-vector 20 5))
 	  (test (length big2) 20)
 	  (let ((big3 (make-int-vector 20 0)))
@@ -914,16 +949,17 @@
     ))
 (clear-and-gc)
 
-(when (> total-memory (* 68 big-size))
-  (let ((v (make-vector big-size)))
-    (do ((i 0 (+ i 1)))
-	((= i big-size))
-      (vector-set! v i (* 2.0 i)))
-    (test (vector-ref v 100000000000) (* 2 100000000000))
-    (test (vector-ref v (- big-size 10000000)) (* 2 (- big-size 10000000)))))
+(define (v-loop-test)
+  (when (> total-memory (* 20 big-size))
+    (let ((v (make-vector big-size)))
+      (do ((i 0 (+ i 1000)))
+	  ((= i big-size))
+	(vector-set! v i (* 2 i)))
+      (test (vector-ref v 100000000) (* 2 100000000))
+      (test (vector-ref v (- big-size 10000000)) (* 2 (- big-size 10000000))))))
+(v-loop-test)
 (clear-and-gc)
 
-
 (define (vector-fft rl im n dir)
   (when rl
     (let ((tempr 0.0)
@@ -1116,8 +1152,8 @@
 	(set! mx (max mx (abs (vector-ref fvr 0 i)) (abs (vector-ref fvr 1 i)))))
       (format () "noise: ~A~%" mx))))
 
-(define (vector-2d-test)
-  (let ((fvr (make-vector (list 2 fft-size) 0.0)))
+(define (vector-2d-test skip)
+  (let ((fvr (make-vector (list skip fft-size) 0.0)))
     (do ((i 0 (+ i 1))
 	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
 	((= i fft-size))
@@ -1127,14 +1163,14 @@
     (vector-2d-fft #f fft-size 1)
     (vector-2d-checker #f)))
 
-(vector-2d-test)
+(vector-2d-test 2)
 (clear-and-gc)
 
 
 ;; --------------------------------------------------------------------------------
 (format () "~%blocks...~%")
 
-(when (> total-memory (* 5 big-size))
+(when (> total-memory (* 10 big-size))
   (clear-and-gc)
   (let ((bigv (make-block big-size)))
     (test (length bigv) big-size)
@@ -1147,6 +1183,12 @@
     ))
 (clear-and-gc)
 
+(when (> total-memory (* (ash 1 33) 8))
+  (let ((b (make-block (ash 1 33))))
+    (set! (b (+ (ash 1 32) 10)) 1.0)
+    (test (b (+ (ash 1 32) 10)) 1.0))
+  (clear-and-gc))
+
 (define (block-fft rl im n dir)
   (when rl
     (do ((i 0 (+ i 1))
@@ -1334,7 +1376,7 @@
 
 (format () "~%hash-tables...~%")
 
-(when (> total-memory (* 9 2147483648))
+(when (> total-memory (* 9 (ash 1 31)))
   (clear-and-gc)
   
   (set! big-size 2000000000)
@@ -1351,7 +1393,7 @@
   (clear-and-gc)
   )
 
-(when (> total-memory (* 9 4294967296)) ; add some slack
+(when (> total-memory (* 9 (ash 1 32))) ; add some slack
   (set! big-size 2500000000)
   (let ((bigv (make-hash-table big-size)))
     (test (length bigv) 4294967296)
@@ -1622,8 +1664,7 @@
 (clear-and-gc)
 
 (format () "~%sundries...~%")
-;; TODO: move to string section
-(set! fft-size (ash 1 15))
+;(set! fft-size (ash 1 15))
 
 (define (string-fft rl im n dir)
   (when rl
@@ -1945,7 +1986,7 @@
   `(make-vector (make-list (+ 1 (random 4)) (+ 1 (random 4))) ,val))
 
 (define-expansion (old-value ref)
-  `((make-shared-vector ,ref (list 1)) 0))
+  `((subvector ,ref '(1)) 0))
 
 (define (complex-2d-fft data n dir)
   (when data
@@ -2198,6 +2239,81 @@
 (iterator-vector-test)
 (clear-and-gc)
 
+(define (complex-closure-fft data n dir)
+  (when data
+    (do ((i 0 (+ i 1))
+	 (j 0))
+	((= i n))
+      (if (> j i)
+	  (let ((temp (vector-ref data j)))
+	    (vector-set! data j (vector-ref data i))
+	    (vector-set! data i temp)))
+      (let ((m (/ n 2)))
+	(do () 
+	    ((not (<= 2 m j)))
+	  (set! j (- j m))
+	  (set! m (/ m 2)))
+	(set! j (+ j m))))
+    (let ((ipow (floor (log n 2)))
+	  (prev 1))
+      (do ((lg 0 (+ lg 1))
+	   (mmax 2 (* mmax 2))
+	   (pow (/ n 2) (/ pow 2))
+	   (theta (complex 0.0 (* pi dir)) (* theta 0.5)))
+	  ((= lg ipow))
+	(let ((wpc (exp theta))
+	      (wc 1.0))
+	  (do ((ii 0 (+ ii 1)))
+	      ((= ii prev))
+	    (do ((jj 0 (+ jj 1))
+		 (i ii (+ i mmax))
+		 (j (+ ii prev) (+ j mmax)))
+		((>= jj pow))
+	      (let ((tc (* wc ((vector-ref data j))))) 
+		(vector-set! data j (let ((z (- ((vector-ref data i)) tc))) (lambda () z)))
+		(vector-set! data i (let ((z (+ ((vector-ref data i)) tc))) (lambda () z)))))
+	    (set! wc (* wc wpc)))
+	  (set! prev mmax))))
+    data))
+
+(define (complex-closure-checker fvr)
+  (when fvr
+    (let ((pk 0.0)
+	  (mx 0.0)
+	  (mxloc 0))
+      (do ((i 0 (+ i 1)))
+	  ((= i fft-size))
+	(set! pk (magnitude ((vector-ref fvr i))))
+	(when (> pk mx)
+	  (set! mx pk)
+	  (set! mxloc i)))
+      (format () "~A ~A~%" mxloc (/ (* 2 (sqrt mx)) fft-size))
+      (format () "~A ~A~%" 
+	      (magnitude ((vector-ref fvr 4)))
+	      (magnitude ((vector-ref fvr (- fft-size 4))))))
+    (vector-set! fvr 4 (let ((z 0.0)) (lambda () z)))
+    (vector-set! fvr (- fft-size 4) (let ((z 0.0)) (lambda () z)))
+    (let ((mx 0.0))
+      (do ((i 0 (+ i 1)))
+	  ((= i fft-size))
+	(set! mx (max mx (magnitude ((vector-ref fvr i))))))
+      (format () "noise: ~A~%" mx))))
+
+(define (complex-closure-test)
+  (let ((fvr (make-vector fft-size)))
+    (do ((i 0 (+ i 1))
+	 (x 0.0 (+ x (/ (* 8 pi) fft-size))))
+	((= i fft-size))
+      (vector-set! fvr i (let ((z (sin x))) (lambda () z))))
+    (complex-closure-fft fvr fft-size 1)
+    (complex-closure-checker fvr)
+    (complex-closure-fft #f fft-size 1)
+    (complex-closure-checker #f)))
+(complex-closure-test)
+
+(clear-and-gc)
+
+
 (s7-version)
 
 ;(*s7* 'memory-usage)
