@@ -1,35 +1,27 @@
 (if (not (provided? 'snd-peak-phases.scm)) (load "peak-phases.scm"))
 (load "primes.scm")
 
-(define (vector-find-if func vect)
-  (let ((len (length vect))
-	(result #f))
-    (do ((i 0 (+ i 1)))
-	((or (= i len)
-	     result)
-	 result)
-      (set! result (func (vector-ref vect i))))))
-
 (define (get-best choice n)
-  (vector-find-if (lambda (val)
-		    (and (vector? val)
-			 (= (vector-ref val 0) n)
-			 (let ((a-val (vector-ref val 1))
-			       (a-len (length val))
-			       (a-data (vector-ref val 2)))
-			   (do ((k 3 (+ 1 k)))
-			       ((= k a-len))
-			     (if (and (real? (vector-ref val k))
-				      (< (vector-ref val k) a-val))
-				 (begin
-				   (set! a-val (vector-ref val k))
-				   (set! a-data (vector-ref val (+ k 1))))))
-			   (list a-val a-data))))
-		  (case choice 
-		    ((:all) noid-min-peak-phases)
-		    ((:odd) nodd-min-peak-phases)
-		    ((:even) neven-min-peak-phases)
-		    (else primoid-min-peak-phases))))
+  (let ((val (vector-ref (case choice 
+			   ((:all) noid-min-peak-phases)
+			   ((:odd) nodd-min-peak-phases)
+			   ((:even) neven-min-peak-phases)
+			   (else primoid-min-peak-phases))
+			 (cond ((<= n 128) (- n 1))
+			       ((= n 256) 128)
+			       ((= n 512) 129)
+			       ((= n 1024) 130)
+			       (else 131)))))
+    (let ((a-val (vector-ref val 1))
+	  (a-len (length val))
+	  (a-data (vector-ref val 2)))
+      (do ((k 3 (+ 1 k)))
+	  ((= k a-len)
+	   (list a-val a-data))
+	(when (and (real? (vector-ref val k))
+		   (< (vector-ref val k) a-val))
+	  (set! a-val (vector-ref val k))
+	  (set! a-data (vector-ref val (+ k 1))))))))
 
 (define (write-best-cases)
   (let ((file (open-output-file "best.data" "w")))
@@ -72,41 +64,42 @@
 
     (close-output-port file)))
 
-
 (define (min-peak choice n)
-  (vector-find-if (lambda (val)
-		    (and (vector? val)
-			 (= (vector-ref val 0) n)
-			 (let ((a-val (vector-ref val 1))
-			       (a-len (length val)))
-			   (do ((k 2 (+ k 1)))
-			       ((>= k a-len))
-			     (if (and (vector? (vector-ref val k))
-				      (not (= n (length (vector-ref val k)))))
-				 (let-temporarily ((*s7* 'print-length) 4)
-				   (format () "~A ~D[~D]: vector length = ~D (~A ~A)~%" 
-					   choice n k 
-					   (length (vector-ref val k))
-					   (vector-ref val (- k 1))
-					   (vector-ref val k))))
-			     (if (not (or (number? (vector-ref val k))
-					  (vector? (vector-ref val k))))
-				 (format () "~A ~D[~D]: bad entry: ~A (a-len: ~A)~%" choice n k (vector-ref val k) a-len))
-			     (if (vector? (vector-ref val k))
-				 (let ((v (vector-ref val k)))
-				   (do ((i 0 (+ i 1)))
-				       ((= i (length v)))
-				     (if (> (abs (vector-ref v i)) 2.0)
-					 (format () "~A ~D[~D][~D]: needs mod: ~A~%" choice n k i (vector-ref v i))))))
-			     (if (and (real? (vector-ref val k))
-				      (< (vector-ref val k) a-val))
-				 (set! a-val (vector-ref val k))))
-			   a-val)))
-		  (case choice
-		    ((:all) noid-min-peak-phases)
-		    ((:odd) nodd-min-peak-phases)
-		    ((:even) neven-min-peak-phases)
-		    (else primoid-min-peak-phases))))
+  (let ((val (vector-ref (case choice 
+			   ((:all) noid-min-peak-phases)
+			   ((:odd) nodd-min-peak-phases)
+			   ((:even) neven-min-peak-phases)
+			   (else primoid-min-peak-phases))
+			 (cond ((<= n 128) (- n 1))
+			       ((= n 256) 128)
+			       ((= n 512) 129)
+			       ((= n 1024) 130)
+			       (else 131)))))
+    (let ((a-val (vector-ref val 1))
+	  (a-len (length val)))
+      (do ((k 2 (+ k 1)))
+	  ((>= k a-len))
+	(if (and (vector? (vector-ref val k))
+		 (not (= n (length (vector-ref val k)))))
+	    (let-temporarily ((*s7* 'print-length) 4)
+	      (format () "~A ~D[~D]: vector length = ~D (~A ~A)~%" 
+		      choice n k 
+		      (length (vector-ref val k))
+		      (vector-ref val (- k 1))
+		      (vector-ref val k))))
+	(if (not (or (number? (vector-ref val k))
+		     (vector? (vector-ref val k))))
+	    (format () "~A ~D[~D]: bad entry: ~A (a-len: ~A)~%" choice n k (vector-ref val k) a-len))
+	(if (vector? (vector-ref val k))
+	    (let ((v (vector-ref val k)))
+	      (do ((i 0 (+ i 1)))
+		  ((= i (length v)))
+		(if (> (abs (vector-ref v i)) 2.0)
+		    (format () "~A ~D[~D][~D]: needs mod: ~A~%" choice n k i (vector-ref v i))))))
+	(if (and (real? (vector-ref val k))
+		 (< (vector-ref val k) a-val))
+	    (set! a-val (vector-ref val k))))
+      a-val)))
 
 (define (get-worst-overall choice choices)
   (let ((diffs (make-vector 116))
