@@ -19,6 +19,7 @@
 		     ("tgen.scm" . "v-gen")
 		     ("tall.scm" . "v-all")
 		     ("snd-test.scm" . "v-call")
+		     ("dup.scm" . "v-dup")
 		     ))
 
 (define (last-callg)
@@ -56,22 +57,23 @@
          ;;              my $space = ' ' x max($CC_col_widths->[$i] - length($count), 0);
 	 (format *stderr* "~NC ~A~D -> ~A~D: ~NC~%" 8 #\space outfile (- next 1) outfile next 8 #\space)
 	 (system (format #f "./snd compare-calls.scm -e '(compare-calls \"~A~D\" \"~A~D\")'" outfile (- next 1) outfile next)))))
-   (list (list "repl" "tmac.scm")
-	 (list "snd -noinit" "tpeak.scm")
+   (list (list "snd -noinit" "tpeak.scm")
+	 (list "repl" "tmac.scm")
+	 (list "repl" "dup.scm")
 	 (list "repl" "tref.scm")
 	 (list "snd -noinit" "make-index.scm")
 	 (list "repl" "tauto.scm")
 	 (list "repl" "teq.scm")
 	 (list "repl" "s7test.scm")
 	 (list "repl" "lt.scm")
-	 (list "repl" "tcopy.scm")
 	 (list "repl" "tread.scm")
+	 (list "repl" "tcopy.scm")
 	 (list "repl" "tform.scm")
 	 (list "repl" "tlet.scm")
 	 (list "repl" "tfft.scm")
 	 (list "repl" "tmap.scm")
-	 (list "repl" "tsort.scm")
 	 (list "repl" "titer.scm")
+	 (list "repl" "tsort.scm")
 	 ;(list "repl" "lg.scm")
 	 (list "repl" "thash.scm")
 	 (list "snd -noinit" "tgen.scm")    ; repl here + cload sndlib was slower
